==> publieditor.content-0.5.tar.gz: publieditor.content-0.5/setup.py <==
# http://www.28lines.com/?p=8
import os
import re
from setuptools import setup, find_packages
from setuptools.command.test import test


class TestRunner(test):
    def run(self, *args, **kwargs):
        if self.distribution.install_requires:
            self.distribution.fetch_build_eggs(
                self.distribution.install_requires)
        if self.distribution.tests_require:
            self.distribution.fetch_build_eggs(
                self.distribution.tests_require)
        from publieditor.content.tests.runtests import runtests
        runtests()


def get_data_files(*args, **kwargs):

    EXT_PATTERN = kwargs.get('ext') or '\.(html|js|txt|css|po|mo|png|json|xml|yml|odt)'

    data_dict = {}
    for pkg_name in args:
        data_files = []
        for dirpath, dirnames, filenames in os.walk(pkg_name.replace('.', '/')):
            rel_dirpath = re.sub("^" + pkg_name + '/', '',  dirpath)
            # Ignore dirnames that start with '.'
            for i, dirname in enumerate(dirnames):
                if dirname.startswith('.'): del dirnames[i]
            if filenames:
                data_files += [os.path.join(rel_dirpath, f) for f in filenames
                               if re.search(EXT_PATTERN, f)]
        data_dict[pkg_name] = data_files
    return data_dict

setup(
    name='publieditor.content',
    namespace_packages=['publieditor'],
    version="0.5",
    description='PUBLIEDITOR CONTENT', 
    author='Thunder Systems',
    url='http://hg/thundersystems.it/jmb/publieditor.content',
    author_email='dev@thundersystems.it',
    packages=find_packages(exclude=['tests', 'tests.*']),
    platforms='any',
    zip_safe=False,
    classifiers=[
        'Environment :: Jumbo',
        'Operating System :: OS Independent',
        'Programming Language :: Python',
        'Topic :: Internet :: WWW/HTTP :: Dynamic Content',
        'Framework :: Django',
        'Framework :: Jumbo',
    ],
    test_suite="publieditor.content.tests",
    cmdclass={"test": TestRunner},
    install_requires=[
        'setuptools',
        'beautifulsoup',
        'python-dateutil',
        'babel',
        'ftfy',
        'jmb.core>=0.4',
        'jmb.i18n',
        'jmb.tag',
        'jmb.content',
        'django-filer',
        'publieditor.oldapp',
        'publieditor.universe',
        'publieditor.contract',
    ],
    package_data=get_data_files('publieditor.content')
)

==> publieditor.content-0.10.tar.gz: publieditor.content-0.10/setup.py <==
# http://www.28lines.com/?p=8
import os
import re
from setuptools import setup, find_packages
from setuptools.command.test import test


class TestRunner(test):
    def run(self, *args, **kwargs):
        if self.distribution.install_requires:
            self.distribution.fetch_build_eggs(
                self.distribution.install_requires)
        if self.distribution.tests_require:
            self.distribution.fetch_build_eggs(
                self.distribution.tests_require)
        from publieditor.content.tests.runtests import runtests
        runtests()


def get_data_files(*args, **kwargs):

    EXT_PATTERN = kwargs.get('ext') or '\.(html|js|txt|css|po|mo|png|json|xml|yml|odt|gif)'

    data_dict = {}
    for pkg_name in args:
        data_files = []
        for dirpath, dirnames, filenames in os.walk(pkg_name.replace('.', '/')):
            rel_dirpath = re.sub("^" + pkg_name + '/', '',  dirpath)
            # Ignore dirnames that start with '.'
            for i, dirname in enumerate(dirnames):
                if dirname.startswith('.'): del dirnames[i]
            if filenames:
                data_files += [os.path.join(rel_dirpath, f) for f in filenames
                               if re.search(EXT_PATTERN, f)]
        data_dict[pkg_name] = data_files
    return data_dict

setup(
    name='publieditor.content',
    namespace_packages=['publieditor'],
    version="0.10",
    description='PUBLIEDITOR CONTENT', 
    author='Thunder Systems',
    url='http://hg/thundersystems.it/jmb/publieditor.content',
    author_email='dev@thundersystems.it',
    packages=find_packages(exclude=['tests', 'tests.*']),
    platforms='any',
    zip_safe=False,
    classifiers=[
        'Environment :: Jumbo',
        'Operating System :: OS Independent',
        'Programming Language :: Python',
        'Topic :: Internet :: WWW/HTTP :: Dynamic Content',
        'Framework :: Django',
        'Framework :: Jumbo',
    ],
    test_suite="publieditor.content.tests",
    cmdclass={"test": TestRunner},
    install_requires=[
        'setuptools',
        'beautifulsoup',
        'python-dateutil',
        'babel',
        'ftfy',
        'jmb.core>=0.4',
        'jmb.i18n',
        'jmb.tag',
        'jmb.content',
        'django-filer',
        'publieditor.oldapp',
        'publieditor.universe',
        'publieditor.contract',
    ],
    package_data=get_data_files('publieditor.content')
)
